;; Generated package description from rcirc-sqlite.el  -*- no-byte-compile: t -*-
(define-package "rcirc-sqlite" "1.0.1.0.20240422.191938" "rcirc logging in SQLite" '((emacs "30.0")) :commit "a2dca3182572ab2af7018a91186dbf9bcb2db2b5" :authors '(("Matto Fransen" . "matto@matto.nl")) :maintainer '("Matto Fransen" . "matto@matto.nl") :keywords '("comm") :url "https://codeberg.org/mattof/rcirc-sqlite")
